@@ -23,18 +23,20 @@ CONF = cfg.CONF
 
 APARAMS = utils.get_agent_params()
 
-INSPECTION_DEFAULT_COLLECTOR = 'default,logs'
+INSPECTION_DEFAULT_COLLECTORS = 'default,logs'
 INSPECTION_DEFAULT_DHCP_WAIT_TIMEOUT = 60
 
 cli_opts = [
     cfg.StrOpt('api_url',
                default=APARAMS.get('ipa-api-url'),
                regex='^(mdns|http(s?):\\/\\/.+)',
-               help='URL of the Ironic API. '
+               help='URL(s) of the Ironic API. '
                     'Can be supplied as "ipa-api-url" kernel parameter.'
-                    'The value must start with either http:// or https://. '
+                    'The value(s) must start with either http:// or https://. '
                     'A special value "mdns" can be specified to fetch the '
-                    'URL using multicast DNS service discovery.'),
+                    'URL using multicast DNS service discovery. If several '
+                    'URLs are provided, all of them are tried until one '
+                    'does not return a connection error.'),
 
     cfg.StrOpt('global_request_id',
                default=APARAMS.get('ipa-global-request-id'),
@@ -155,22 +157,22 @@ cli_opts = [
 
     cfg.StrOpt('inspection_callback_url',
                default=APARAMS.get('ipa-inspection-callback-url'),
-               help='Endpoint of ironic-inspector. If set, hardware inventory '
-                    'will be collected and sent to ironic-inspector '
-                    'on start up. '
+               help='Endpoint(s) to send inspection data to. If set, hardware '
+                    'inventory will be collected and sent there on start up. '
                     'A special value "mdns" can be specified to fetch the '
                     'URL using multicast DNS service discovery. '
                     'Can be supplied as "ipa-inspection-callback-url" '
-                    'kernel parameter.'),
+                    'kernel parameter. If the URL is not provided but '
+                    'inspection_collectors is not empty, the URL is detected '
+                    'from api_url.'),
 
     cfg.StrOpt('inspection_collectors',
-               default=APARAMS.get('ipa-inspection-collectors',
-                                   INSPECTION_DEFAULT_COLLECTOR),
+               default=APARAMS.get('ipa-inspection-collectors'),
                help='Comma-separated list of plugins providing additional '
-                    'hardware data for inspection, empty value gives '
-                    'a minimum required set of plugins. '
+                    'hardware data for inspection. The default are %s. '
                     'Can be supplied as "ipa-inspection-collectors" '
-                    'kernel parameter.'),
+                    'kernel parameter.'
+                    % INSPECTION_DEFAULT_COLLECTORS),
 
     cfg.IntOpt('inspection_dhcp_wait_timeout',
                min=0,
@@ -262,6 +264,31 @@ cli_opts = [
                help='Pre-shared token to use when working with the '
                     'ironic API. This value is typically supplied by '
                     'ironic automatically.'),
+    cfg.StrOpt('image_server_user',
+               default=None,
+               help='Pre-shared username used in Basic Auth process '
+                    'against the http(s) server that hosts the disk image.'
+                    'This variable can be also configured via image_info.'
+                    'Value coming from image_info takes precedence over'
+                    'value coming from command line or configuration file.'),
+    cfg.StrOpt('image_server_password',
+               default=None,
+               help='Pre-shared password used in Basic Auth process '
+                    'against the http(s) server that hosts the disk image.'
+                    'This variable can be also configured via image_info.'
+                    'Value coming from image_info takes precedence over'
+                    'value coming from command line or configuration file.'),
+    cfg.StrOpt('image_server_auth_strategy',
+               default="noauth",
+               help='Option to select authentication strategy used during'
+                    'communication with the server that hosts the disk images'
+                    'and related checksums. This option also turns'
+                    'image_server_password and image_server_user'
+                    'into mandatory variables for those authentication'
+                    'strategies that require username + password credentials.'
+                    'This variable can be also configured via image_info.'
+                    'Value coming from image_info takes precedence over'
+                    'value coming from command line or configuration file.'),
     cfg.BoolOpt('agent_token_required',
                 default=APARAMS.get('ipa-agent-token-required', False),
                 help='Control to enforce if API command requests should '
@@ -343,75 +370,13 @@ cli_opts = [
                 help='If the agent should rebuild the configuration drive '
                      'using a local filesystem, instead of letting Ironic '
                      'determine if this action is necessary.'),
-    cfg.BoolOpt('disable_deep_image_inspection',
-                default=False,
-                help='This disables the additional deep image inspection '
-                     'the agent does before converting and writing an image. '
-                     'Generally, this should remain enabled for maximum '
-                     'security, but this option allows disabling it if there '
-                     'is a compatability concern.'),
-    cfg.ListOpt('permitted_image_formats',
-                default='raw,qcow2',
-                help='The supported list of image formats which are '
-                     'permitted for deployment with Ironic Python Agent. If '
-                     'an image format outside of this list is detected, the '
-                     'image validation logic will fail the deployment '
-                     'process. This check is skipped if deep image '
-                     'inspection is disabled.'),
 ]
 
-disk_utils_opts = [
-    cfg.IntOpt('bios_boot_partition_size',
-               default=1,
-               help='Size of BIOS Boot partition in MiB when configuring '
-                    'GPT partitioned systems for local boot in BIOS.'),
-    cfg.StrOpt('dd_block_size',
-               default='1M',
-               help='Block size to use when writing to the nodes disk.'),
-    cfg.IntOpt('partition_detection_attempts',
-               default=3,
-               min=1,
-               help='Maximum attempts to detect a newly created partition.'),
-    cfg.IntOpt('partprobe_attempts',
-               default=10,
-               help='Maximum number of attempts to try to read the '
-                    'partition.'),
-    cfg.IntOpt('image_convert_memory_limit',
-               default=2048,
-               help='Memory limit for "qemu-img convert" in MiB. Implemented '
-                    'via the address space resource limit.'),
-    cfg.IntOpt('image_convert_attempts',
-               default=3,
-               help='Number of attempts to convert an image.'),
-]
-
-disk_part_opts = [
-    cfg.IntOpt('check_device_interval',
-               default=1,
-               help='After Ironic has completed creating the partition table, '
-                    'it continues to check for activity on the attached iSCSI '
-                    'device status at this interval prior to copying the image'
-                    ' to the node, in seconds'),
-    cfg.IntOpt('check_device_max_retries',
-               default=20,
-               help='The maximum number of times to check that the device is '
-                    'not accessed by another process. If the device is still '
-                    'busy after that, the disk partitioning will be treated as'
-                    ' having failed.')
-]
+CONF.register_cli_opts(cli_opts)
 
 
 def list_opts():
-    return [('DEFAULT', cli_opts),
-            ('disk_utils', disk_utils_opts),
-            ('disk_partitioner', disk_part_opts)]
-
-
-def populate_config():
-    """Populate configuration. In a method so tests can easily utilize it."""
-    CONF.register_cli_opts(cli_opts)
-    CONF.register_opts(disk_utils_opts, group='disk_utils')
-    CONF.register_opts(disk_part_opts, group='disk_partitioner')
+    return [('DEFAULT', cli_opts)]
 
 
 def override(params):
@@ -438,6 +403,3 @@ def override(params):
             LOG.warning('Unable to override configuration option %(key)s '
                         'with %(value)r: %(exc)s',
                         {'key': key, 'value': value, 'exc': exc})
-
-
-populate_config()
